@@ -37,7 +37,7 @@ bool use12HourClock();
 
 TimeEdit::TimeEdit(QWidget* parent)
     : QWidget(parent),
-      mAmPm(Q_NULLPTR),
+      mAmPm(nullptr),
       mAmIndex(-1),
       mPmIndex(-1),
       mReadOnly(false)
